Struct snapper_box::crypto::key::DerivedKey[][src]

pub struct DerivedKey { /* fields omitted */ }
A key that has been derived from a RootKey

This will have an encryption key and an hmac key derived from the RootKey’s entropy pool, using Blake3 in key-derivation mode, keyed with the RootKey’s hmac key.

This struct also contains the context string that was used to derive it, as a way to validate key provenance, or possibly reconstruct a key after a corruption occurs.

Implementations

Encrypts the given DerivedKey into an EncryptedDerivedKey using the given RootKey.

This method packs the derived key into a ClearText box, and then encrypts it to a CipherText box, without enabling compression.

See the documentation for CipherText for a description of the encryption method.

Errors

Will error if the encryption or serialization fail