Struct snapper_box::crypto::key::EncryptedRootKey[][src]

pub struct EncryptedRootKey { /* fields omitted */ }
A RootKey that has been encrypted with an argon2 derivation of a users password

See the RootKey docs for a description of the method used for encryption

Implementations

Attempts to decrypt the key with the provided password, and provide it as a RootKey

Errors

Will return:

  • Error::Argon2Failure if the argon2 key derivation fails
  • Error::BadHmac if the hmac verification failed, either due to incorrect password or corruption
  • Error::KeyDeserialization if the key fails to deserialize, which really shouldn’t happen