Struct snapper_box::crypto::key::Nonce [−][src]
pub struct Nonce(_);Expand description
Nonce/Salt value used in encryption
This is stored as a 24-byte array, for serialization, but is viewable as an XChaCha nonce
Nonces are intended to be always randomly generated, and there is intentionally no API for reconstructing a nonce.
Implementations