Module snapper_box::crypto::types[][src]

Intermediate types used for encryption and decryption HAZMAT

This module provides wrapper types for shuffling data back and forth between encrypted and unencrypted representations, as well as the ability to, optionally, transparently compress plaintext before encryption.

DANGER

This module deals in low level cryptographic details. It is advisable to not deal with this module directly, and instead use a higher level API.

Structs

An encrypted plaintext, with associated data

An unencrypted blob of plaintext.

Thin wrapper around a const-generic array to make them work better with serde