#[non_exhaustive]pub enum BackendError {
Show 14 variants
BadHMAC,
Argon2Failure {
source: Error,
},
KeyDeserialization,
ItemSerialization,
ItemDeserialization,
Compression {
source: Error,
},
Decompression {
source: Error,
},
SegmentIO {
source: Error,
},
SegmentLength,
NoData,
NoDataIO {
source: Error,
},
InvalidCompression,
EntryIO {
source: Error,
},
InvalidLsmState,
}Expand description
Error type describing faults that can happen during encryption or decryption.
This is a fairly low level type for interacting with the api directly, you probably want
CryptoBoxError
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadHMAC
HMAC tag verification failed
Argon2Failure
An error occurred while deriving a key from a password
KeyDeserialization
Failed to deserialize a key
ItemSerialization
Failed to serialize an item
ItemDeserialization
Failed to deserialize an item
Compression
A error occurred while attempting to compress a blob
Decompression
A error occurred while attempting to decompress a blob
SegmentIO
An underlying IO error occurred while attempting to read a segment
SegmentLength
A length mismatch occurred while parsing a segment
NoData
No data was provided for a segment, not even a length
NoDataIO
Suspected no data provided, please see IO error for details
InvalidCompression
Invalid compression flag in serialized data
EntryIO
Failed reading/writing an entry
InvalidLsmState
Indicates an invalid state where an LsmFile’s internal state points to a
value that doesn’t exist