Enum snapper_box::error::Error[][src]

#[non_exhaustive]
pub enum Error {
Show 14 variants BadHMAC, Argon2Failure { source: Error, }, KeyDeserialization, ItemSerialization, ItemDeserialization, Compression { source: Error, }, Decompression { source: Error, }, SegmentIO { source: Error, }, SegmentLength, NoData, NoDataIO { source: Error, }, InvalidCompression, EntryIO { source: Error, }, InvalidLsmState,
}
Error type describing faults that can happen during encryption or decryption.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadHMAC

HMAC tag verification failed

Argon2Failure

An error occurred while deriving a key from a password

Fields of Argon2Failure

source: Error

The underlying error

KeyDeserialization

Failed to deserialize a key

ItemSerialization

Failed to serialize an item

ItemDeserialization

Failed to deserialize an item

Compression

A error occurred while attempting to compress a blob

Fields of Compression

source: Error

Underlying zstd error

Decompression

A error occurred while attempting to decompress a blob

Fields of Decompression

source: Error

Underlying zstd error

SegmentIO

An underlying IO error occurred while attempting to read a segment

Fields of SegmentIO

source: Error

Underlying error

SegmentLength

A length mismatch occurred while parsing a segment

NoData

No data was provided for a segment, not even a length

NoDataIO

Suspected no data provided, please see IO error for details

Fields of NoDataIO

source: Error

Underlying error

InvalidCompression

Invalid compression flag in serialized data

EntryIO

Failed reading/writing an entry

Fields of EntryIO

source: Error

Underlying error

InvalidLsmState

Indicates an invalid state where an LsmFile’s internal state points to a value that doesn’t exist