Struct snapper_box::crypto::key::EncryptedRootKey [−][src]
pub struct EncryptedRootKey { /* fields omitted */ }Expand description
Implementations
Attempts to decrypt the key with the provided password, and provide it as a RootKey
Errors
Will return:
Error::Argon2Failureif the argon2 key derivation failsError::BadHmacif the hmac verification failed, either due to incorrect password or corruptionError::KeyDeserializationif the key fails to deserialize, which really shouldn’t happen