Struct snapper_box::crypto::types::CipherText [−][src]
pub struct CipherText<'a> { /* fields omitted */ }Expand description
An encrypted plaintext, with associated data
This structure contains the payload, encrypted with XChaCha20, the nonce that was used to encrypt
it, as well as the HMAC of the encrypted payload. It also includes a flag indicating whether or not
to treat the plaintext as compressed
Implementations
Attempts to decrypt the Ciphertext with the given key, turning it into a Cleartext. This will
also decompress the payload, if it was compressed.
Errors
Will return:
Error::BadHMAC- If the hmac tag fails to validate (decryption failure)Error::Decompression- If compressed data fails to decompress
Returns true if this CipherText is compressed