Enum snapper_box::error::Error [−][src]
#[non_exhaustive]
pub enum Error {
Show 14 variants
BadHMAC,
Argon2Failure {
source: Error,
},
KeyDeserialization,
ItemSerialization,
ItemDeserialization,
Compression {
source: Error,
},
Decompression {
source: Error,
},
SegmentIO {
source: Error,
},
SegmentLength,
NoData,
NoDataIO {
source: Error,
},
InvalidCompression,
EntryIO {
source: Error,
},
InvalidLsmState,
}Expand description
Error type describing faults that can happen during encryption or decryption.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
HMAC tag verification failed
An error occurred while deriving a key from a password
Fields of Argon2Failure
source: ErrorThe underlying error
Failed to deserialize a key
Failed to serialize an item
Failed to deserialize an item
A error occurred while attempting to compress a blob
Fields of Compression
source: ErrorUnderlying zstd error
A error occurred while attempting to decompress a blob
Fields of Decompression
source: ErrorUnderlying zstd error
An underlying IO error occurred while attempting to read a segment
Fields of SegmentIO
source: ErrorUnderlying error
A length mismatch occurred while parsing a segment
No data was provided for a segment, not even a length
Suspected no data provided, please see IO error for details
Fields of NoDataIO
source: ErrorUnderlying error
Invalid compression flag in serialized data
Failed reading/writing an entry
Fields of EntryIO
source: ErrorUnderlying error
Indicates an invalid state where an LsmFile’s internal state points to a
value that doesn’t exist